==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_fields/TRANSACTIONLINEID.java <==

package net.datastream.schemas.mp_fields;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINENUM" minOccurs="0"/>
 *         <element ref="{http://schemas.datastream.net/MP_fields}SUBLINE" minOccurs="0"/>
 *       </sequence>
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "transactionlinenum",
    "subline"
})
@XmlRootElement(name = "TRANSACTIONLINEID")
public class TRANSACTIONLINEID {

    @XmlElement(name = "TRANSACTIONID", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "TRANSACTIONLINENUM")
    protected Long transactionlinenum;
    @XmlElement(name = "SUBLINE")
    protected Long subline;

    /**
     * Gets the value of the transactionid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Sets the value of the transactionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Gets the value of the transactionlinenum property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getTRANSACTIONLINENUM() {
        return transactionlinenum;
    }

    /**
     * Sets the value of the transactionlinenum property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setTRANSACTIONLINENUM(Long value) {
        this.transactionlinenum = value;
    }

    /**
     * Gets the value of the subline property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSUBLINE() {
        return subline;
    }

    /**
     * Sets the value of the subline property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSUBLINE(Long value) {
        this.subline = value;
    }

}

==> eam-wshub-proxyclient-12.1-4-sources.jar: net/datastream/schemas/mp_fields/TRANSACTIONLINEID.java <==

package net.datastream.schemas.mp_fields;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONID"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}TRANSACTIONLINENUM" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}SUBLINE" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "transactionid",
    "transactionlinenum",
    "subline"
})
@XmlRootElement(name = "TRANSACTIONLINEID")
public class TRANSACTIONLINEID {

    @XmlElement(name = "TRANSACTIONID", required = true)
    protected TRANSACTIONID_Type transactionid;
    @XmlElement(name = "TRANSACTIONLINENUM")
    protected Long transactionlinenum;
    @XmlElement(name = "SUBLINE")
    protected Long subline;

    /**
     * Gets the value of the transactionid property.
     * 
     * @return
     *     possible object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public TRANSACTIONID_Type getTRANSACTIONID() {
        return transactionid;
    }

    /**
     * Sets the value of the transactionid property.
     * 
     * @param value
     *     allowed object is
     *     {@link TRANSACTIONID_Type }
     *     
     */
    public void setTRANSACTIONID(TRANSACTIONID_Type value) {
        this.transactionid = value;
    }

    /**
     * Gets the value of the transactionlinenum property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getTRANSACTIONLINENUM() {
        return transactionlinenum;
    }

    /**
     * Sets the value of the transactionlinenum property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setTRANSACTIONLINENUM(Long value) {
        this.transactionlinenum = value;
    }

    /**
     * Gets the value of the subline property.
     * 
     * @return
     *     possible object is
     *     {@link Long }
     *     
     */
    public Long getSUBLINE() {
        return subline;
    }

    /**
     * Sets the value of the subline property.
     * 
     * @param value
     *     allowed object is
     *     {@link Long }
     *     
     */
    public void setSUBLINE(Long value) {
        this.subline = value;
    }

}
